@@ -606,7 +606,8 @@ class Agent(Insight, Channel, Catalog, Dataset):
         # Check if dataset exists
         dataset_id = self.get_dataset_by_slug(self._slug, slug)
 
-        dataframe = dataframe.where(pd.notnull(dataframe), None)
+        dataframe = dataframe.replace({np.nan: None})
+
         if(dataset_id != None):
             #If it exists update it
             self.update_dataset(dataframe, dataset_name, slug, icon_url, settings)
